@@ -89,6 +89,7 @@ positional.add_argument(
     metavar='URL',
     help="""
     The scheme defaults to 'http://' if the URL does not include one.
+    (You can override this with: --default-scheme=https)
 
     You can also use a shorthand for localhost
 
@@ -212,7 +213,7 @@ output_processing.add_argument(
     """.format(
         default=DEFAULT_STYLE,
         available='\n'.join(
-            '{0}{1}'.format(8*' ', line.strip())
+            '{0}{1}'.format(8 * ' ', line.strip())
             for line in wrap(', '.join(sorted(AVAILABLE_STYLES)), 60)
         ).rstrip(),
     )
@@ -576,7 +577,7 @@ ssl.add_argument(
 troubleshooting = parser.add_argument_group(title='Troubleshooting')
 
 troubleshooting.add_argument(
-    '--ignore-stdin',
+    '--ignore-stdin', '-I',
     action='store_true',
     default=False,
     help="""
@@ -611,6 +612,14 @@ troubleshooting.add_argument(
 
     """
 )
+troubleshooting.add_argument(
+    '--default-scheme',
+    default="http",
+    help="""
+    The default scheme to use if not specified in the URL.
+
+    """
+)
 troubleshooting.add_argument(
     '--debug',
     action='store_true',
